

def get_instance(settings):
    return None


def add_user_info(project, g):
    project["author"] = "changeme"
    project["author_email"] = "changeme"


def project_url(project, g):
    return "changeme"
